
# q-expansion of newform 7232.2.a.bf, downloaded from the LMFDB on 03 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 7232
weight = 2
poly_data = [-2, 10, -4, -34, 16, 42, -3, -13, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-32, 64, 130, -153, -203, 40, 65, -2, -5], 1], [[-39, 92, 148, -210, -242, 56, 78, -3, -6], 1], [[-39, 94, 148, -210, -242, 56, 78, -3, -6], 1], [[66, -144, -272, 353, 467, -88, -154, 4, 12], 1], [[74, -162, -288, 386, 476, -100, -155, 5, 12], 1], [[-90, 210, 378, -536, -666, 140, 219, -7, -17], 1], [[108, -228, -470, 562, 784, -138, -257, 6, 20], 1], [[116, -268, -474, 650, 820, -166, -270, 8, 21], 1]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -1, 0, 0, 0, 0], [-1, 0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0], [-1, 0, 0, -1, 0, 0, 0, 1, 0], [2, 0, 0, 0, 0, 1, 0, 0, -1], [0, -1, 0, 0, 0, 0, 1, 0, -1], [0, -1, 1, -1, 0, 0, 0, 0, 0], [-3, 2, 1, 0, 0, 0, -1, 0, 1], [-1, 0, 0, 1, 0, 0, -1, -2, 0], [-2, 0, 1, -1, 0, 1, -1, 0, 0], [2, 0, 0, 0, 2, 0, -1, -1, 0], [-1, -2, 0, 1, 1, 1, 0, 0, -1], [-1, -1, 1, 0, 0, 1, 0, 0, -1], [-2, -2, 0, 0, 0, -1, 2, -1, -1], [0, 0, 0, 0, 1, -1, 0, 2, 1], [-3, 0, 0, 1, 0, 0, -1, -2, 1], [-1, 1, 2, -1, 0, 0, 0, 2, 0], [-1, 2, 1, 0, -3, 0, 1, 2, 1], [1, 0, 0, 1, 2, -1, 0, 0, 1], [1, -1, -3, 2, 0, 0, 1, 2, -1], [0, 0, 0, 0, 2, 0, 2, 2, -1], [4, 0, 0, -2, -2, 1, 1, 2, 0], [2, 2, 0, 0, -2, 1, 0, 0, 1], [-1, 0, -1, 0, 0, 0, 2, 0, -2], [2, -4, -3, 1, -1, 0, 1, 0, 1], [-3, -1, 0, 3, 2, 0, 0, -2, -2], [-2, 2, 0, 0, 2, -2, -3, 1, 1], [1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 2, 0, 0, 0, 0, -2, 0, 1], [1, -2, -2, -3, 0, 1, -1, 0, 0], [-1, 2, 2, 1, -2, -1, 1, 0, 0], [-6, -2, -4, 2, 0, 0, -1, 2, 2], [1, 0, 0, 1, 4, -1, -1, 0, 2], [1, 0, -1, 0, -3, -1, 1, 0, 0], [-2, 0, -2, 2, 2, 0, -2, -1, 4], [-9, 2, -2, -1, -2, 1, 0, 0, 3], [-3, 0, 1, 2, -1, 1, 2, 0, -1], [-2, 2, 0, 0, 2, 2, 1, -3, -3], [0, 3, 0, 0, -2, 3, -2, 2, 5], [4, -2, 3, -1, 2, 0, -1, 0, -1], [-2, 0, 1, 1, -1, 1, -3, 2, 4], [-5, 2, 0, -1, 0, 1, -6, 0, 1], [-1, 0, -3, 2, 0, 0, 0, -2, 0], [-2, 4, -1, 3, 1, 0, 0, -4, 0], [-6, 2, 0, 2, 6, -1, -2, 2, 1], [2, -1, 1, -3, -4, 1, 0, -2, -1], [0, -2, 4, 0, 2, 2, 0, -4, -2], [3, 2, 3, 0, -2, 1, -2, 0, -1], [-2, -4, 0, 4, 2, 0, 3, 1, 0], [-7, -2, 0, -1, 4, -3, -2, 0, 2], [-3, 2, -2, 3, 4, -3, 0, -1, 0], [7, 2, 2, 3, 2, 1, 2, -4, -1], [1, 0, -2, -1, -4, -2, 1, 0, 5], [-6, 4, -1, -1, -1, -2, 1, 4, 1], [-5, 2, 1, 2, -2, -1, 0, 2, 3], [-9, 0, -1, 2, 1, -3, 2, 4, 3], [3, 0, 0, 3, 2, -1, 0, -4, -1], [2, 0, 0, 0, 2, 1, 1, 0, 2], [-12, 2, 0, -4, -2, 1, 1, 0, 1], [5, -2, 3, -2, -2, 1, 0, -2, -3], [-3, -2, -2, 1, 4, -1, 4, -4, -3], [-13, 2, -2, -1, 2, -5, -2, 0, 0], [-7, 2, -2, -1, 0, -3, -2, 1, 0], [-3, 2, 4, -3, 2, 3, 0, 3, 1], [-5, -2, -2, -1, -4, 0, 1, 0, 2], [5, 2, 2, -5, -2, 1, -1, 1, -1], [-1, 4, -2, -1, 0, -5, -3, 0, 2], [0, -2, -3, 1, -2, 2, 1, 4, -1], [0, 2, 0, 2, -2, 4, -2, 1, 1], [-8, 2, 5, 3, 3, 0, -2, -4, 0], [0, -4, 0, 0, 2, 3, 3, 2, -6], [11, -2, 3, 0, -4, 4, 3, 0, 1], [1, 0, 6, 1, -5, 4, 2, -2, -4], [-10, -2, 2, 0, 2, 1, 2, 2, 0], [-5, -4, 0, 3, 6, -1, -3, -5, 0], [-8, 0, 5, 1, 4, -1, 5, -2, -4], [-1, 2, 2, -3, -2, 0, -3, -1, 0], [0, -2, -8, 2, -2, -4, 0, 6, 2], [5, -1, -2, -3, 2, 1, -3, 0, -2], [-1, 2, 0, -1, 0, 2, -6, 2, 4], [-19, 2, 3, 0, 5, 2, -3, -6, 1], [0, 2, -2, -4, -8, -2, -1, 6, 5], [-1, 4, 4, -3, 4, -4, -4, -2, 2], [-1, -2, 2, -1, -8, 1, -2, 2, 4], [8, -2, -8, 2, 2, -2, -4, 0, 6], [3, 2, 4, 3, -4, -1, -2, -4, 3], [-5, 2, -4, 3, 0, -3, 0, 0, -1], [1, 0, 0, -1, 6, 2, 1, -2, -3], [10, -4, 0, -2, -4, 0, 5, -2, -4], [0, 5, 1, -1, 4, 2, -4, 4, 2], [-8, -3, -1, 1, 2, -2, -5, -8, -5], [17, -5, -2, 1, 2, 0, 3, -2, -1], [-5, 3, 0, -3, 4, 0, -2, -2, 0], [0, 0, -6, -2, -4, -2, -1, 4, 1], [0, 2, 4, -6, -6, 0, 0, -4, 2], [3, 0, 2, -3, 2, 4, 2, 0, 0], [-16, 5, -2, 2, 4, -4, -1, 4, 3], [-8, -2, -3, 1, 6, 0, -5, 4, -1], [-3, 6, 6, -3, 0, 4, 0, -4, -3], [-2, 0, 0, 0, 6, 2, 4, 1, -4], [-7, 4, -2, 5, 0, 0, -3, -2, 3], [1, -2, 6, -5, -4, 1, -2, 2, -3], [-3, -2, -2, -3, 1, -1, 3, -4, -2], [13, -8, -6, 3, -2, 2, 0, -4, -2], [3, 0, 2, -1, 2, -1, -3, -4, -6], [-1, 0, 2, 1, 0, 1, -5, -2, 0], [8, -3, -1, 1, -2, 3, 4, 2, -1], [-7, -2, -2, 3, 2, -4, -5, -8, -1], [-2, 4, -1, 3, 1, -5, 1, -2, -2], [11, 4, 3, 0, -6, -3, 3, 2, -2], [-6, 6, -4, -4, -8, -1, -3, 1, 3], [-6, 0, 6, 0, -1, 4, 1, 0, -5], [-12, -1, 3, 1, -4, -3, 3, 2, 0], [3, -8, 0, -1, -4, -1, 3, 4, -2], [-11, 4, 0, -5, -5, 4, 2, 2, -2], [5, -4, 4, -1, 0, -2, 2, -6, -6], [-7, 2, 4, 1, -6, 3, -9, 0, 4], [0, 4, 6, 2, -7, 5, -4, 2, 1], [1, 0, 5, 0, -4, 0, 0, -6, 0], [13, 0, 8, -3, 4, 3, 1, 2, -2], [-11, 6, 2, -5, 2, -4, 1, -2, 1], [0, 2, 10, -2, 3, 0, -6, 0, 4], [-5, -6, -6, -1, 4, -1, -1, 0, 4], [9, 4, 5, 0, -6, -1, -3, -4, 2], [7, 0, 0, -1, 6, -1, -3, -9, -6], [-5, 6, -8, -3, 2, 3, -1, 4, 3], [16, -2, -4, -4, -12, 2, 0, 4, -3], [-9, 2, 7, -8, -2, -1, 0, 0, 3], [-11, 2, 2, 1, -6, -2, -9, 0, 4], [9, 2, 3, 4, 5, 5, -1, 0, -6], [1, -1, -1, 0, 4, 0, 2, -6, -6], [-11, -2, -1, -6, -4, 0, -5, 2, 1], [-3, 4, -10, 3, -2, -2, 4, 5, 5], [3, -2, 2, -3, 4, -2, 2, -3, -7], [6, -4, 2, 6, -8, 3, -2, -2, -1], [-10, -8, 0, 2, 2, 5, 2, 0, -4], [8, 2, 9, -3, 8, 1, 2, 0, -3], [-12, 2, 0, -2, 0, -1, -1, 1, 3], [7, 6, 0, 1, 1, -2, -2, 2, 6], [8, -2, -8, -2, -6, -4, 2, 4, 4], [1, 8, 2, -3, -4, -1, -1, 0, 0], [0, -2, 8, 0, -10, 1, 0, 0, 0], [-12, 0, -9, 3, -6, -2, 0, 4, 0], [5, 1, -3, 6, -2, -1, 3, -4, -2], [12, 10, 2, 0, -6, 6, -5, -9, -1], [-1, 2, -2, -3, 14, -3, -3, 2, 0], [-7, -7, -8, 7, -6, -4, -1, -6, 1], [8, -6, -2, 2, 6, 2, 1, 0, -9], [-20, 2, -1, -5, 4, -1, 2, 4, 7], [-2, 2, 2, 2, -8, -5, 9, 4, 0], [12, -4, -2, -2, -9, 1, 0, -2, 3], [0, -2, -5, -3, -7, -1, 0, 2, 1], [-7, -7, -4, 3, 4, -2, 6, -2, -6], [0, 2, 0, 0, 8, -1, -7, -2, 8], [9, -8, -10, 1, 6, 1, 0, -4, -3], [19, 2, 2, 1, -4, -2, 2, 2, 0], [11, 0, 4, 3, 2, 1, -2, 0, -3], [-11, -6, -3, 4, -2, 1, 8, 0, -3], [0, -2, -2, 2, -1, 4, -2, 0, 4], [-9, -2, -2, 1, 6, 4, -1, -3, 0], [4, 4, 2, -6, -4, 2, -9, 4, 1], [15, -1, 0, 1, -12, -2, 3, -2, -5], [3, -4, 6, 1, 8, 0, 3, -12, -7], [1, -3, -11, 2, -6, -1, -3, -4, 6], [-11, -2, 0, -5, 2, 2, -4, 2, 4], [-4, -4, -1, 3, 0, 3, 9, 6, 0], [7, -2, 2, 1, 0, 0, -4, 7, 3], [3, 2, 2, -3, -4, -7, 4, 4, -5], [9, -4, -2, 5, -2, 4, 8, 2, -4], [-9, 0, -6, 1, 6, 2, 2, 2, -2], [15, -4, 2, -1, 0, 4, -5, -6, -7], [-15, -4, -2, -1, 2, 1, 4, 2, 1], [5, -6, -4, -1, 8, 0, 7, -2, -9], [0, 6, -4, 2, 4, 2, -1, -1, 2], [-5, 11, 2, -5, -2, 1, -2, 8, 7], [4, 2, -6, -8, 6, -4, -1, 7, 3], [4, 7, -1, -3, 0, 1, 2, 2, -1], [-8, -2, 2, 4, 0, 3, 1, -2, 0], [8, 2, 7, 1, -3, -1, 7, -2, -4], [16, -3, -6, -2, 2, -4, 11, 0, -9], [3, 0, -3, -2, -10, 1, 5, 6, -4], [1, -2, 8, -7, 2, 1, -1, -4, 0], [-2, 4, 9, 1, 9, 1, -2, -2, -5], [-12, -4, -7, 9, -2, 4, 4, 4, -2], [4, -6, 6, 0, 2, -1, 12, 6, -5], [-27, 4, 6, -3, 0, 2, -8, 0, -1], [23, -6, -2, 1, -4, 5, 6, 3, 2], [0, -15, -9, 1, 0, 1, 1, 2, -6], [-1, 4, -4, -9, -6, 1, -2, 2, 3], [-3, -4, -4, 7, 5, -6, -5, -6, 7], [14, -2, 8, -10, 2, 1, -3, 2, -2], [-3, -8, 0, -3, -8, 5, 1, 4, 2], [-7, 8, -2, -3, -2, 1, 2, 4, -3], [-6, -4, 4, 0, 14, -6, -7, 0, -1], [0, -4, -2, -4, 12, 1, -2, -2, -1], [1, 8, 2, -1, 2, 0, 2, 10, 0], [16, -12, 0, -2, 2, 7, 3, -1, -7], [-5, -5, -1, -2, 4, -2, 8, 2, 0], [-16, -2, -4, 2, -6, -4, -9, -7, 7], [-1, -3, -1, 2, 10, 0, 5, -6, -9], [-24, -2, 3, 3, 16, -3, 0, 2, 3], [3, 6, 8, -9, -2, 5, 5, -2, -4], [4, 8, 4, -4, 4, 5, -6, -10, -3], [23, -2, 3, -4, 0, 4, 3, 0, -3], [-16, 4, -2, -6, 2, -3, 3, 2, -1], [-4, -12, -4, 8, 5, 3, -4, -2, -5], [-25, 10, 4, -1, -2, -5, 1, 8, 4], [-3, 5, -4, -1, 4, -9, -6, -4, 5], [20, -8, 0, -2, 12, 1, -4, -4, -5], [-3, 6, -11, 4, 2, -3, -2, 2, 3], [-10, 8, 4, 6, 4, -4, -7, 4, 10], [-5, 2, -10, -1, 10, -2, -4, 0, 1], [20, 2, 1, 3, -9, 5, -4, -2, -5], [7, 4, -2, -3, -12, 6, 3, 6, 5], [-13, -4, -9, 6, 5, -2, -4, 6, 2], [13, -4, 6, -1, 0, 4, 5, -2, -3], [18, -2, -10, 8, -8, 4, 8, -8, -6], [15, -10, -1, 8, -4, -4, 3, -6, -7], [-8, -2, -6, 4, 2, 2, 9, -1, -7], [-20, -1, -5, 9, 6, 1, -6, -2, -3], [14, -8, -8, 4, 6, -3, 5, 2, -8], [-20, 6, 5, -1, 7, 3, -7, -10, 6], [-18, 1, 0, 2, 10, 3, -2, 2, 3], [-7, 4, 1, -4, -12, -6, -2, 12, 8], [8, -2, -8, 6, -6, 0, -10, -4, 0], [-7, -6, -2, 1, -6, -3, 4, -4, 0], [-13, 4, -4, 9, 8, 1, -2, 0, -1], [15, 0, -10, 7, 2, -2, 1, -6, -1], [0, 2, -4, 2, -10, 2, 6, 0, -2], [-11, -3, -12, 7, 0, 2, 1, 2, 5], [-5, -8, 2, 11, -2, -3, 1, -8, -1], [-14, 10, 4, -4, 8, -2, -9, 4, 3], [-15, -2, -2, 9, 6, 0, 2, -4, -5], [11, 2, -4, 1, -2, 3, 6, 8, 3], [15, -2, -2, 5, -6, 3, 3, -14, -8], [9, -2, 7, -2, 6, 5, -2, -8, -5], [-2, 6, 8, 2, 0, 0, 2, -2, 3], [-5, 9, 3, -14, -2, 3, -5, 8, 2], [7, 7, -2, 3, 0, 2, 4, -2, -2], [10, -6, 0, 6, -6, 3, 0, -8, 2], [12, 1, 7, -3, 2, 7, 7, -6, -8], [4, 12, 3, -1, -10, -4, -2, 2, 4], [-13, 0, 4, 3, 4, 2, -1, -4, -1], [26, -8, -3, -7, 3, 6, 6, 0, -8], [-7, 4, 6, 1, -10, -1, -1, 0, 1], [11, 2, 2, -1, 4, -4, -3, -2, 9], [7, 2, 0, -7, 1, -8, 11, -2, -7], [10, 12, 4, 2, -10, 4, 0, 4, 1], [2, -2, 0, 4, 0, -3, 8, 11, -3], [10, 2, 2, -2, -6, -4, 8, -2, 2], [-1, 2, -4, -3, -2, -5, -3, 12, 11], [-4, 6, 0, -2, -6, -3, -10, -2, 7], [-2, 10, 14, -6, 0, -3, 1, -6, 2], [9, 1, -8, -1, -2, -1, 2, 0, -3], [1, 10, 11, 2, -2, -3, -6, 0, 11], [-14, 7, -6, -4, 14, -4, 1, 4, 1], [-7, -2, -7, 4, -8, 2, 11, -4, 3], [1, 2, 4, -3, 18, -2, 1, 0, -3], [-9, -6, 6, 3, -2, -1, -1, -12, -4], [-25, 6, 6, -5, -4, 1, -7, -2, 3], [16, -4, -2, -8, -4, -1, 1, 13, -4], [1, 4, -2, -5, -16, 1, 1, 0, 2], [0, 2, 12, -10, -4, -1, -3, -1, -1], [-3, 6, -6, 9, -2, -3, -4, -6, 4], [3, 6, -2, 5, -2, -9, -5, -4, 8], [-14, -6, -4, -4, -8, -1, 3, -3, -3], [14, -6, -12, 6, 2, 4, -1, -6, -4], [19, 2, -7, 2, -4, 0, -1, -4, -3], [12, -4, 5, -3, 0, -1, 3, -8, 2], [12, -6, 4, -4, -4, 0, -6, 4, 6], [-10, 10, -6, 10, 2, 0, -10, 0, 6], [11, -4, -2, -9, -4, -1, 2, 0, -6], [22, -6, 0, 4, -10, -1, 12, 0, -1], [-16, -4, 14, -6, -4, -1, 7, 2, -6], [15, 3, -4, 5, -2, -3, -2, -8, -5], [37, -6, 1, 0, 6, 1, 0, -8, -7], [-9, 0, -2, 9, -8, -6, -11, -8, 9], [3, 9, 10, -5, 2, 1, -9, -4, 0], [26, 2, -4, 2, -2, 7, 3, -2, -3], [4, -6, -9, 5, 3, 1, -5, -14, -4], [2, 4, 5, 1, -5, 1, -5, -6, 4], [-2, 6, -4, 4, -4, 1, -2, 7, 3], [-26, -2, -8, 2, -7, 3, 9, -2, 4], [22, -14, -10, 4, -2, 3, 1, -2, 2], [7, 10, 0, 3, 6, -4, 3, -6, -1], [20, -12, -2, 0, -16, 2, 6, 8, 0], [38, 4, 9, 1, -3, 7, 7, -2, -2], [18, -4, 0, -4, -16, -1, 6, 4, 3], [0, 10, 15, -9, 4, -3, -12, -2, -1], [-5, -4, -2, 3, 2, -6, 0, 10, 10], [-14, -12, 0, -4, -8, 1, 0, 2, -1], [-11, 2, -6, 1, 7, 3, 1, 4, 4], [-4, -4, 9, -7, -12, 7, 1, 4, 0], [18, -8, -4, 8, 14, 2, -2, -3, -4], [0, 4, 4, -4, -10, 0, -2, 20, 15], [-4, 6, 2, -4, -8, 6, -13, 4, 3], [-23, 10, 8, -9, -9, 7, 2, 8, -1], [-6, -4, -4, 2, 3, -4, -11, -4, 5], [3, -2, 10, -7, -4, 5, 4, 5, -6], [9, -12, -9, -2, -6, 3, 9, 6, 6], [13, -7, 5, 6, -6, 1, -2, -8, -5], [-6, -10, -8, 6, -2, 3, 4, -4, -4], [-16, -4, -2, 2, -3, 3, 1, 2, -6], [-3, 0, -14, 3, 0, 0, 3, 0, -3], [-19, 0, -10, 5, -2, -5, 5, -2, -3], [-31, 6, 9, -12, -4, 2, 7, 2, -1], [-23, -1, -9, 0, 4, -17, -2, 8, 5], [-3, -2, 5, 12, 2, -3, 12, -2, -7], [-11, -12, -9, 12, -1, 8, 3, 2, 3], [3, -6, -7, -6, -4, 2, 1, 6, 1], [-10, -2, -10, -2, -4, -4, 1, 0, 3], [-18, -2, 0, -2, 6, 1, -4, -6, -1], [5, -4, 2, -7, -8, -8, 4, 10, 11], [21, -10, -6, 3, 0, 1, 4, -6, -3], [-6, 4, -6, 12, 1, 0, -9, 0, 1], [-23, 8, -12, 3, 2, -9, 2, 4, 10], [-11, 2, 4, 1, -10, -3, -7, 2, 4], [2, 2, -4, 0, 8, 0, 1, 5, -4], [-11, 8, 10, -7, -6, 3, -3, -6, -9], [10, 8, 6, 10, -6, 5, -3, -2, 4], [-10, -6, 11, 5, 16, -3, 6, -14, -7], [-15, 6, 2, 5, -10, -2, 1, 2, 7], [-15, 4, -6, -1, -10, 3, -4, 6, 7], [-10, 4, 4, 4, -4, -10, -6, 7, 13], [15, -2, 14, -5, 8, 0, -1, -8, 0], [14, 2, 12, 10, -2, 4, 2, -8, -4], [15, 2, -2, 11, -4, 5, 6, 4, -1], [8, -2, 1, -3, -8, -3, 4, 16, 7], [-8, 12, -1, -9, 2, 0, -4, 10, 10], [15, -2, -1, 0, 4, 6, -5, -10, -9], [-34, 7, 7, -5, 6, -1, -13, -2, 2], [-8, 5, 8, 0, 2, 4, 4, -12, -8], [-7, 6, 6, -3, -2, 4, -8, -6, 4], [-8, 2, -4, 0, -12, -3, 3, 14, 8], [21, 0, 0, -7, -2, -1, 1, 7, 8], [28, 2, 0, -6, -12, 0, -3, -7, -4], [2, 6, -2, -6, 0, 3, -11, 0, 8], [-13, -3, -3, -8, 2, 3, 2, 0, -3], [-9, 0, 9, -2, 8, 0, -8, 0, 4], [6, 0, 0, 4, -12, 5, 4, -6, -3], [9, 4, 6, -1, -4, 4, 2, -1, 2], [0, 6, 2, 6, 6, -4, 10, 4, -5], [-1, -2, 9, -2, -8, -2, -3, -4, 1], [17, -15, -4, 3, 12, -4, 8, -6, -10], [-10, 8, 8, -8, -14, 2, 8, 9, 10], [15, -2, 2, -1, -8, 2, 6, -8, 3], [-17, 8, -8, -7, 4, -10, 1, 10, 2], [-22, 0, 4, 0, 0, 1, -5, -1, 8], [6, 4, -4, -2, -4, 1, 5, 12, -1], [12, -8, -4, 2, 0, -9, 2, -1, -2], [-10, -8, -8, 8, 0, -5, -9, -5, -2], [17, 5, 11, -4, -4, -3, -9, -4, -8], [11, -4, -6, 1, 4, 8, 2, 3, -4], [10, -10, 4, -4, -14, -1, 4, 0, -7], [-17, 6, -8, -7, -8, 2, -5, 6, 7], [-11, 4, -2, -3, 11, 6, -6, 6, 0], [16, 4, 8, 6, 0, 1, 4, 0, 3], [7, -10, 0, 1, -6, 4, 10, 6, 0], [-2, 8, -8, 0, 0, 3, -6, 6, 3], [-15, 4, 20, 5, 14, -3, 4, -12, -9], [5, -2, -1, 4, 9, -9, -2, -8, -11], [5, 3, -4, 7, 4, 3, 8, -16, -7], [-21, 6, 14, -9, -11, -4, 4, 2, 8], [-19, 0, -2, 7, -6, 1, 8, -9, -4], [-9, 12, 12, -9, 8, -5, -11, 4, 4], [-13, -8, -3, 0, 7, -5, 11, 4, -10], [32, 4, 2, -8, -8, -4, 6, -4, -2], [-8, 6, 0, -16, -3, -9, 0, -2, 5], [21, 4, -2, 5, 16, 4, 10, 0, -9], [-12, -4, 0, -12, 4, 7, -9, -2, 7], [-28, -6, 6, 4, 6, 8, -11, -1, -1], [-2, 2, -1, 3, 1, -4, -6, -8, 4], [8, 2, -5, -5, -14, 0, 1, -6, 1], [39, -2, -4, -11, -17, 2, 5, 6, -1], [11, -10, 2, -5, -6, 2, 2, 10, -3], [14, 0, -6, 10, 0, -5, 4, 0, -3], [22, -8, -2, 6, 12, 4, -2, -12, -2], [0, -12, 4, 2, 0, -1, 12, 4, -11], [6, 4, 2, -10, 2, -4, 1, -8, -3], [-7, -4, 4, -3, -12, 3, 5, 2, 2], [-39, 5, -1, -8, -6, -1, 3, 4, 2], [18, -12, -6, 6, 2, 0, 9, -10, 1], [13, -10, -22, 5, 6, 5, 7, 0, -6], [-2, 2, -12, 6, 12, -5, -9, -10, 0], [9, -2, 16, -1, -8, 7, 6, -8, -2], [-27, 6, 9, -8, -18, 9, 0, 8, -3], [-9, 6, -8, 9, -7, 8, -9, 10, 3], [-11, 8, 0, 3, 8, -5, 5, -8, 5], [-25, -6, 8, 3, -12, 2, -4, -6, 0], [1, 4, 9, -4, -4, 6, 0, 14, 6], [-16, -4, 0, -4, -2, -6, -2, -4, -2], [-22, 17, -8, 6, 2, -2, -5, -4, 15], [16, 0, -8, 16, 6, -7, 8, -6, 0], [-17, 2, 6, -3, 10, -2, 3, 8, 13], [16, -6, -4, 4, 0, -4, 9, -12, -1], [-2, 10, -4, 0, 14, -6, -8, 8, 14], [-1, -12, 2, 7, 17, 1, 5, -16, -10], [17, 16, 13, -8, 12, 6, -6, -4, 0], [-12, 6, -3, 5, 14, -8, -5, -2, 3], [37, 2, -10, -5, 2, 1, -11, 0, 4], [-13, 8, -7, -4, 3, 5, -9, 0, 12], [3, 6, 0, -1, 22, 0, 3, -4, -7], [-49, 2, 0, -1, 12, -4, -7, -3, -3], [-6, 6, 9, 5, -7, -2, -2, -4, 8], [19, 2, 2, -7, 2, -3, 2, -3, 1], [20, 2, -8, -2, 0, -1, -5, 8, 2], [-10, 14, -4, -2, -4, 4, -1, -6, -2], [-4, 2, -8, 4, -7, 0, -14, 4, 14], [15, -20, -6, -3, 6, -2, 8, -7, -13], [-26, 2, 7, -7, -10, 2, -7, 8, 3], [-2, -2, -12, 2, -6, -3, -5, 6, 18], [-32, 4, 0, 12, 4, -10, -5, -4, 5], [7, 6, 6, 1, 20, -1, 2, -5, -14], [-15, 6, 4, 5, 12, -11, -6, 4, 1], [5, 1, 5, -2, -6, 13, 4, 0, -15], [-2, 4, 14, -4, 16, 0, -9, 0, 1], [4, -8, -8, 6, 4, 0, 4, -12, 0], [-11, 13, 1, -14, -8, 9, -5, 4, 6], [6, -8, 1, 7, 16, -1, 5, 6, 0], [-32, -4, -1, -1, 4, -1, -5, 0, 10], [9, -10, -8, 7, 0, 4, -2, -2, 11], [-3, 6, -2, 9, 2, -2, -1, 10, 9], [13, 0, -2, 7, 0, 7, 3, 12, -6], [-26, -12, -3, 3, 10, 2, 2, -2, -2], [28, -2, -20, 8, 2, 2, 2, 2, 3], [-10, 18, 4, -12, -16, -3, -3, 8, 10], [-22, 14, 4, 2, 1, -1, -1, -2, 14], [25, 8, 4, -13, 14, -6, -17, 6, 3]]
